# Changelog

## 0.7.0 - 2025-08-25
- Added: Ability to write text to the title screen.
- Removed: Anti-Softlock option.

# TODO: retroactively fill this in <_<

## 0.4.1 - 2025-05-22

### Visual
- Changed: Base Minimap Edits has been updated to reflect new events, boss tiles, and security rooms.

## 0.4.0 - 2025-05-15
- Changelog Created
- Added: 6 new Item Locations. 3 Major/Events: Boiler, Animals, Auxiliary Power. 3 Minor/Tanks: Subzero Containment, Quarantine Bay, Northeast Stabilizer
- Added: Infrastructure to define base minimap edits that will always apply.
